GtkWidget* create_resume_popup();

char* get_search_string(char* str);

// inserting search result in resume
void resume_insert_file(resume_t* resume, file_t* file);
// loading incomplete file list from disk
void resume_list_load(char* fname, int import);
// save incomplete file list to disk
void resume_list_save();
// adding a transfer to incomplete list
void resume_list_add(resume_t* resume);
void resume_clist_add(resume_t* resume);
// removing resume from list (on finish or delete)
void resume_list_stop(resume_t* resume, transfer_t* transfer);
void resume_list_freeze(resume_t* resume);
void resume_list_thaw(resume_t* resume);
void resume_list_remove(resume_t* resume, transfer_t* transfer);
void resume_list_delete(resume_t* resume);
resume_t* resume_list_search_filename(char* filename);
// searching file in incomplete list
resume_t* resume_list_search_file(file_t* file);
// searching transfer in incomplete list
resume_t* resume_list_search(transfer_t* transfer);
// updating resume (visual)
void resume_list_update(resume_t* resume, int full);
// perform new search on incomplete file
void resume_search(resume_t* resume, int search);
// removing all search results for incomplete file
void resume_remove_search(resume_t* resume);
// try to download from next user in result list
void resume_try_next_potential(resume_t* resume);
// set user flag in potential list
void resume_user_flag(resume_t* resume, char* user, int flag);

void resume_search_all();

int resume_timer(gpointer data);

void resume_user_online(char* user, int link);
void resume_user_offline(char* user);

